@@ -1,4 +1,4 @@
-from typing import Sequence, List, Union, Optional
+from typing import Sequence, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
@@ -26,10 +26,8 @@ class TaggingDataset(NLPDataset):
         text_segmenter: str = "char",
         text_dtype: tf.DType = tf.int32,
         label_dtype: tf.DType = tf.int32,
-        text_padding_shape: tuple = (None,),
-        label_padding_shape: tuple = (None,),
-        text_padding_value: Union[str, int, float, None] = None,
-        label_padding_value: Union[str, int, float, None] = 0,
+        batch_padding_shapes: Optional[Tuple[tf.DType]] = ((None,), (None,)),
+        batch_padding_values: Optional[Tuple[tf.DType]] = (0, 0),
     ):
         self.vocab = vocab
         self.start_tag = start_tag
@@ -41,12 +39,12 @@ class TaggingDataset(NLPDataset):
             in_memory=in_memory,
             text_segmenter=text_segmenter,
             max_length=max_length,
+            na_value="",
+            column_dtypes=["str", "str"],
             text_dtype=text_dtype,
             label_dtype=label_dtype,
-            text_padding_shape=text_padding_shape,
-            label_padding_shape=label_padding_shape,
-            text_padding_value=text_padding_value or vocab[vocab.pad],
-            label_padding_value=label_padding_value,
+            batch_padding_shapes=batch_padding_shapes,
+            batch_padding_values=batch_padding_values,
         )
 
     @property
@@ -79,15 +77,9 @@ class TaggingDataset(NLPDataset):
         shuffle: bool = True,
         shuffle_buffer_size: Optional[int] = None,
     ) -> tf.data.Dataset:
-        dataset = (
-            self.shuffled_dataset(shuffle_buffer_size) if shuffle else self._dataset
-        )
-        return (
-            dataset.padded_batch(
-                batch_size,
-                padded_shapes=(self.text_padding_shape, self.label_padding_shape),
-                padding_values=(self.text_padding_value, self.label_padding_value),
-            )
-            .map(_combine_xy)
-            .prefetch(buffer_size=tf.data.experimental.AUTOTUNE)
+        return super().batchify(
+            batch_size,
+            shuffle=shuffle,
+            shuffle_buffer_size=shuffle_buffer_size,
+            after_batch=_combine_xy,
         )
