@@ -2,7 +2,6 @@ from typing import Sequence, List, Dict, Any, Optional
 
 import tensorflow as tf
 from tensorflow.keras.initializers import TruncatedNormal
-from tensorflow.keras.layers import InputSpec
 from tensorflow.keras.layers.experimental.preprocessing import TextVectorization
 
 from official.modeling import activations
@@ -108,6 +107,40 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         }
 
 
+class BertPairPreprocessingLayer(BertPreprocessingLayer):
+    def call(self, inputs: List[tf.Tensor]) -> List[tf.Tensor]:
+        query, context = inputs
+        query_token_ids = self.tokenizer.tokenize(query)
+        context_token_ids = self.tokenizer.tokenize(context)
+        query_flatten_ids = query_token_ids.merge_dims(-2, -1)
+        context_flatten_ids = context_token_ids.merge_dims(-2, -1)
+        cls_ids = tf.reshape(
+            tf.tile(
+                tf.constant([self.cls_id], dtype=tf.int64), [query_token_ids.nrows()]
+            ),
+            [query_token_ids.nrows(), 1],
+        )
+        sep_ids = tf.reshape(
+            tf.tile(
+                tf.constant([self.sep_id], dtype=tf.int64), [query_token_ids.nrows()]
+            ),
+            [query_token_ids.nrows(), 1],
+        )
+        query_ids = tf.concat([cls_ids, query_flatten_ids, sep_ids], axis=1)
+        context_ids = tf.concat([context_flatten_ids, sep_ids], axis=1)
+        type_ids = tf.concat(
+            [
+                tf.zeros_like(query_ids, dtype=tf.int64),
+                tf.ones_like(context_ids, dtype=tf.int64),
+            ],
+            axis=1,
+        )
+        return (
+            tf.concat([query_ids, context_ids], axis=1, name="token_ids").to_tensor(0),
+            type_ids.to_tensor(0),
+        )
+
+
 class BertLayer(tf.keras.layers.Layer):
     """
     copy from https://github.com/tensorflow/models/blob/v2.2.0/official/nlp/modeling/networks/transformer_encoder.py.
@@ -186,25 +219,25 @@ class BertLayer(tf.keras.layers.Layer):
         )
         if share_layer:
             self.shared_layer = layers.Transformer(
-            num_attention_heads=num_attention_heads,
-            intermediate_size=intermediate_size,
-            intermediate_activation=activation,
-            dropout_rate=dropout_rate,
-            attention_dropout_rate=attention_dropout_rate,
-            kernel_initializer=initializer,
-            name="transformer",
-            )
-        else:
-            self.transformer_layers = []
-            for i in range(num_layers):
-                layer = layers.Transformer(
                 num_attention_heads=num_attention_heads,
                 intermediate_size=intermediate_size,
                 intermediate_activation=activation,
                 dropout_rate=dropout_rate,
                 attention_dropout_rate=attention_dropout_rate,
                 kernel_initializer=initializer,
-                name="transformer/layer_%d" % i,
+                name="transformer",
+            )
+        else:
+            self.transformer_layers = []
+            for i in range(num_layers):
+                layer = layers.Transformer(
+                    num_attention_heads=num_attention_heads,
+                    intermediate_size=intermediate_size,
+                    intermediate_activation=activation,
+                    dropout_rate=dropout_rate,
+                    attention_dropout_rate=attention_dropout_rate,
+                    kernel_initializer=initializer,
+                    name="transformer/layer_%d" % i,
                 )
                 self.transformer_layers.append(layer)
 
@@ -217,8 +250,11 @@ class BertLayer(tf.keras.layers.Layer):
             )
         super().__init__(name=name, **kwargs)
 
-    def call(self, inputs: List[tf.Tensor]) -> tf.Tensor:
-        token_ids, type_ids, masks = inputs
+    def call(
+        self, inputs: List[tf.Tensor], mask: Optional[tf.Tensor] = None
+    ) -> tf.Tensor:
+        token_ids, type_ids = inputs
+        mask = self.compute_mask(inputs, mask=mask)
         word_embeddings = self.embedding_layer(token_ids)
         position_embeddings = self.position_embedding_layer(word_embeddings)
         type_embeddings = self.type_embedding_layer(type_ids)
@@ -230,7 +266,7 @@ class BertLayer(tf.keras.layers.Layer):
         if self.embedding_projection is not None:
             embeddings = self.embedding_projection(embeddings)
         data = embeddings
-        attention_mask = layers.SelfAttentionMask()([data, masks])
+        attention_mask = layers.SelfAttentionMask()([data, mask])
         encoder_outputs = []
         if self.share_layer:
             for _ in range(self.num_layers):
@@ -248,9 +284,16 @@ class BertLayer(tf.keras.layers.Layer):
         if self.cls_pooling:
             cls_output = self.cls_output_layer(cls_output)
         if self.return_all_encoder_outputs:
-            return [encoder_outputs, cls_output]
+            return [encoder_outputs, mask, cls_output]
         else:
-            return [encoder_outputs[-1], cls_output]
+            return [encoder_outputs[-1], mask, cls_output]
+
+    def compute_mask(
+        self, inputs: List[tf.Tensor], mask: Optional[tf.Tensor] = None
+    ) -> tf.Tensor:
+        if mask is not None:
+            return mask
+        return tf.math.not_equal(inputs[0], 0)
 
     def get_config(self):
         return {
