@@ -23,6 +23,7 @@ class BertClassifier(DeepClassifier):
         is_multilabel: bool = True,
         segmenter: Optional[str] = None,
         embedding_size: int = 100,
+        use_batch_normalization: bool = True,
         max_sequence_length: int = 120,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
@@ -39,6 +40,7 @@ class BertClassifier(DeepClassifier):
             segmenter=segmenter,
             algorithm="bert",
             embedding_size=embedding_size,
+            use_batch_normalization=use_batch_normalization,
             max_sequence_length=max_sequence_length,
             text2vec=text2vec,
             **kwargs
