@@ -144,9 +144,7 @@ class DeepClassifier(SupervisedNLPModel):
         predictions = self.predict(
             dataset=dataset, thresholds=thresholds, batch_size=batch_size
         )
-        return classification_fscore(
-            dataset.label, predictions, self.is_multilabel, classes=self.classes
-        )
+        return classification_fscore(dataset.label, predictions, classes=self.classes)
 
     @classmethod
     def format_score(cls, score_df: pd.DataFrame, format: str = "markdown") -> str:
