@@ -24,6 +24,7 @@ class BertTagger(DeepTagger):
         classes: Sequence[str],
         segmenter: Optional[str] = None,
         embedding_size: int = 100,
+        use_batch_normalization: bool = True,
         max_sequence_length: int = 120,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
@@ -39,6 +40,7 @@ class BertTagger(DeepTagger):
             segmenter=segmenter,
             algorithm="bert",
             embedding_size=embedding_size,
+            use_batch_normalization=use_batch_normalization,
             max_sequence_length=max_sequence_length,
             start_tag="[CLS]",
             end_tag="[SEP]",
@@ -96,7 +98,9 @@ class BertTagger(DeepTagger):
             epsilon=self.fc_epsilon,
             name="mlp",
         )(embeddings)
-        return CrfLossLayer(self.num_classes)([emissions, tag_ids], mask)
+        return CrfLossLayer(
+            self.num_classes, max_sequence_length=self.max_sequence_length
+        )([emissions, tag_ids], mask)
 
     @classmethod
     def _filter_config(cls, config: Dict[str, Any]) -> Dict[str, Any]:
