@@ -96,7 +96,6 @@ class DeepTagger(SupervisedNLPModel):
     def get_monitor(cls) -> str:
         return "val_fscore"
 
-    @classmethod
     def create_dataset_from_df(
         self, df: pd.DataFrame, vocab: Vocab, segmenter: str, labels: Sequence[str]
     ) -> TaggingDataset:
@@ -147,7 +146,7 @@ class DeepTagger(SupervisedNLPModel):
         dataset: TaggingDataset = None,
         batch_size: int = 128,
     ) -> pd.DataFrame:
-        dataset = self._prepare_dataset(X, y, dataset)
+        dataset = self.prepare_dataset(X, y, dataset)
         predictions = self.predict(dataset=dataset, batch_size=batch_size)
         labels = list(set([c.split("-")[-1] for c in self.classes if "-" in c]))
         return tagging_fscore(dataset.text, dataset.label, predictions, labels)
@@ -193,4 +192,5 @@ class DeepTagger(SupervisedNLPModel):
         return {
             **super().get_custom_objects(),
             "CrfDecodeLayer": CrfDecodeLayer,
+            "Orthogonal": tf.keras.initializers.Orthogonal,
         }
\ No newline at end of file
